@@ -257,6 +257,10 @@ def _PyScript(env, target, source, command = "python $SOURCES", capture=None, ex
 
     if execute: command = execute + " " + basename
 
+    ftargets = [t + ".force" for t in target]
+    if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
+        command = ["mv %s %s" %(f,t) for f,t in zip(ftargets,target)]
+
     gen = lambda source, target, env, for_signature: command_sig if for_signature else command
     return env.Command(target, source, CommandGeneratorAction(gen,{}), *args, **kwargs)
 
@@ -302,7 +306,7 @@ def _PyScons(env, target, source, scons, execute=None, options="-Q", sig_options
     if reduce(lambda a,b: a&b, (os.path.exists(t) for t in ftargets)):
         cmd = ["mv %s %s" %(f,t) for f,t in zip(ftargets,target)]
 
-    gen = lambda source, target, env, for_signature: sig if for_signature else cmd 
+    gen = lambda source, target, env, for_signature: sig if for_signature else cmd
     return env.Command(target, source + [scons], CommandGeneratorAction(gen,{}))
 
 PyScons = DefaultEnvironmentCall("PyScons")
@@ -337,16 +341,12 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
             try: targets.append((int(a[3:]), args[a]))
             except: pass
 
-    myname = args["n"]
-    N = len(os.path.split(myname))
-
     if "exclude" in args: #exlude files names listed in this file from SHIP.tz2
         exclude = set(L.strip() for L in file(args["exclude"]))
     else: exclude = set()
 
     basename = args["temp"]
-    bn = list(os.path.split(basename))
-    env.SConsignFile(os.path.join(*([".."] * N + bn + [".sconsign"])))
+    env.SConsignFile(os.path.join(env.GetLaunchDir(), basename, "sconsign"))
 
     sources = [a for i,a in sorted(sources)]
     targets = [a for i,a in sorted(targets)]
@@ -368,7 +368,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
     SIGNATURES = os.path.join(basename, ".sconsign.dblite")
     ship_source = [s for s in sources if s not in exclude] + [exe, myname]
 
-    if os.path.exists(force):
+    if "print" not in args and os.path.exists(force):
         import subprocess
         print "tar xjf %s" % force
         subprocess.call(["tar xjf ", force])
